#pragma once

#define MAX_SEQ_LEN 5
#define N_INDEX_SIZE 39
#define DATA_SIZE 15777
#define N_CHARS 1321

